Index: tools/SkBitmapRegionDecoderInterface.h |
diff --git a/tools/SkBitmapRegionDecoderInterface.h b/tools/SkBitmapRegionDecoderInterface.h |
index 047f023c808bd4a419befb5d98334e5990140ecd..e1f79bccb66b263d7fcf1f5e8d7e4d2e26a06e56 100644 |
--- a/tools/SkBitmapRegionDecoderInterface.h |
+++ b/tools/SkBitmapRegionDecoderInterface.h |
@@ -19,19 +19,18 @@ class SkBitmapRegionDecoderInterface { |
public: |
enum Strategy { |
- kCanvas_Strategy, // Draw to the canvas, uses SkCodec |
- kOriginal_Strategy, // Sampling, uses SkImageDecoder |
- // TODO (msarett): Add strategy for SkScaledCodec |
+ kCanvas_Strategy, // Draw to the canvas, uses SkCodec |
+ kOriginal_Strategy, // Sampling, uses SkImageDecoder |
+ kAndroidCodec_Strategy, // Uses SkAndroidCodec for scaling and subsetting |
}; |
/* |
- * @param stream Encoded image stream, takes ownership |
+ * @param data Refs the data while this object exists, unrefs on destruction |
* @param strategy Strategy used for scaling and subsetting |
- * @return Tries to create an SkBitmapRegionDecoder, returns NULL |
- * on failure |
+ * @return Tries to create an SkBitmapRegionDecoder, returns NULL on failure |
*/ |
static SkBitmapRegionDecoderInterface* CreateBitmapRegionDecoder( |
- SkStreamRewindable* stream, Strategy strategy); |
+ SkData* data, Strategy strategy); |
/* |
* Decode a scaled region of the encoded image stream |